@@ -1,5 +1,5 @@
 /* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2008 - 2010 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2008 - 2011 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,12 +36,15 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 	token->possibleSentenceStart = false;
 	token->isGeographicalNameInGenitive = false;
 	token->possibleGeographicalName = false;
+	token->possibleMainVerb = false;
 	token->isVerbNegative = false;
 	token->isPositiveVerb = true;
+	token->isConjunction = true;
 	token->requireFollowingVerb = FOLLOWING_VERB_NONE;
 	token->verbFollowerType = FOLLOWING_VERB_NONE;
 	if (token->type != TOKEN_WORD) {
 		token->firstLetterLcase = false;
+		token->isConjunction = false;
 		return;
 	}
 	
@@ -74,14 +77,32 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 				token->isGeographicalNameInGenitive = true;
 			}
 		}
-		if (wclass && wcscmp(L"kieltosana", wclass) == 0) {
+		if (!wclass || wcscmp(L"sidesana", wclass) != 0) {
+			token->isConjunction = false;
+		}
+		
+		if (!wclass) {
+			token->isPositiveVerb = false;
+			token->possibleMainVerb = true;
+		}
+		else if (wcscmp(L"kieltosana", wclass) == 0) {
 			token->isVerbNegative = true;
 			token->isPositiveVerb = false;
-		} else if (!wclass || wcscmp(L"teonsana", wclass) != 0 ||
-			   !negative || wcscmp(L"false", negative) != 0 ||
+		}
+		else if (wcscmp(L"teonsana", wclass) == 0) {
+			if (!negative || wcscmp(L"false", negative) != 0 ||
 			   ((!mood || wcscmp(L"conditional", mood) == 0) && (!person || wcscmp(L"3", person) == 0))) { // "en _lukisi_"
+				token->isPositiveVerb = false;
+			}
+			if ((!mood || (wcscmp(L"A-infinitive", mood) != 0 && wcscmp(L"E-infinitive", mood) != 0)) &&
+			    (!negative || wcscmp(L"true", negative) != 0)) {
+				token->possibleMainVerb = true;
+			}
+		}
+		else {
 			token->isPositiveVerb = false;
 		}
+		
 		if (possibleGeographicalName && wcscmp(L"true", possibleGeographicalName) == 0) {
 			token->possibleGeographicalName = true;
 		}
@@ -124,6 +145,7 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 	morphology::Analyzer::deleteAnalyses(analyses);
 	if (!token->isValidWord) {
 		token->isPositiveVerb = false;
+		token->isConjunction = false;
 	}
 }
 
