@@ -41,14 +41,14 @@ SuggestionGenerator * SuggestionGeneratorFactory::getSuggestionGenerator(
 			return new SuggestionStrategyOcr(voikkoOptions->morAnalyzer, 1000);
 		}
 		else {
-			return new SuggestionStrategyTyping(voikkoOptions->morAnalyzer, 450);
+			return new SuggestionStrategyTyping(voikkoOptions->morAnalyzer, 460);
 		}
 	} else if (backend == "null") {
 		return new SuggestionGeneratorNull();
 	}
 	#ifdef HAVE_HFST
 	if (backend == "hfst") {
-		return new HfstSuggestion(voikkoOptions->dictionary.getMorPath());
+		return new HfstSuggestion(voikkoOptions->dictionary.getMorPath(), voikkoOptions);
 	}
 	#endif
 	throw setup::DictionaryException("Failed to create suggestion generator because of unknown suggestion generator backend");
